import { OnInit, OnChanges, OnDestroy, SimpleChanges, AfterViewInit, ElementRef, EventEmitter, Renderer2, TemplateRef, ChangeDetectorRef } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { ConnectedOverlayPositionChange } from '@angular/cdk/overlay';
export declare type CascaderExpandTrigger = 'click' | 'hover';
export declare type CascaderTriggerType = 'click' | 'hover';
export interface CascaderOption {
    value?: string;
    label?: string;
    title?: string;
    disabled?: boolean;
    loading?: boolean;
    isLeaf?: boolean;
    parent?: CascaderOption;
    children?: CascaderOption[];
    [key: string]: any;
}
export interface DisplayLabelContext {
    labels?: string[];
    selectedOptions?: CascaderOption[][];
}
export declare class CheckCascaderComponent implements OnInit, OnDestroy, OnChanges, AfterViewInit, ControlValueAccessor {
    private _elementRef;
    private _render;
    private _cdr;
    private allowClear;
    private disabled;
    private enableCache;
    private showArrow;
    private showInput;
    private showSearch;
    private changeOnSelect;
    _cmPlaceHolder: string;
    _dropDownPosition: 'top' | 'center' | 'bottom';
    _el: HTMLElement;
    _prefixCls: string;
    _inputPrefixCls: string;
    _focused: boolean;
    menuVisible: boolean;
    _displayLabel: string | TemplateRef<void>;
    _displayLabelIsTemplate: boolean;
    _displayLabelContext: DisplayLabelContext;
    __inputValue: string;
    _inputValue: string;
    _searchValue: any[];
    _lastValue: any[];
    _selectedOptions: CascaderOption[][];
    _activatedOptions: CascaderOption[][];
    _cmColumns: CascaderOption[][];
    _filterColumns: CascaderOption[][];
    private _clickOutsideHandler;
    private _touchOutsideHandler;
    private _delayTimer;
    onChange: any;
    onTouched: any;
    /** Whether is disabled */
    cmDisabled: boolean;
    /** Input size, one of `large` `default` `small` */
    cmSize: 'large' | 'default' | 'small';
    /** Input placeholder */
    cmPlaceHolder: string;
    /** Whether show input box. Defaults to `true`. */
    cmShowInput: boolean;
    /** Whether can search. Defaults to `false`. */
    cmShowSearch: boolean;
    /** Whether allow clear. Defaults to `true`. */
    cmAllowClear: boolean;
    /** Hover text for the clear icon */
    cmClearText: string;
    /** Whether to show arrow */
    cmShowArrow: boolean;
    /** Specify content to show when no result matches. */
    cmNotFoundContent: string;
    /** Additional className of popup overlay */
    cmPopupClassName: string;
    /** Additional className of popup overlay column */
    cmColumnClassName: string;
    /** Options for first column, sub column will be load async */
    cmOptions: CascaderOption[];
    /** Whether cache children when they were loaded asych */
    cmEnableCache: boolean;
    /** Expand column item when click or hover, one of 'click' 'hover' */
    cmExpandTrigger: CascaderExpandTrigger;
    /** Change value on each selection if set to true */
    cmChangeOnSelect: boolean;
    /** Change value on selection only if this function returns `true` */
    cmChangeOn: (option: CascaderOption, level: number) => boolean;
    /** Delay time to show when mouse enter, when `cmExpandTrigger` is `hover`. */
    cmMouseEnterDelay: number;
    /** Delay time to hide when mouse enter, when `cmExpandTrigger` is `hover`. */
    cmMouseLeaveDelay: number;
    /** Triggering mode: can be Array<'click'|'hover'> */
    cmTriggerAction: CascaderTriggerType | CascaderTriggerType[];
    /** Render function of displaying selected options */
    cmDisplayRender: (label: string[], selectedOptions: CascaderOption[]) => string | TemplateRef<any>;
    /** Render function of displaying selected options */
    cmIntervalRender: (label: string[], selectedOptions: CascaderOption[]) => string | TemplateRef<any>;
    /** Property name for getting `value` in the option */
    cmValueProperty: string;
    /** Property name for getting `label` in the option */
    cmLabelProperty: string;
    /** 异步加载数据 */
    cmLoadData: (node: CascaderOption, index?: number) => PromiseLike<any>;
    tabIndex: string;
    /** Event: emit on popup show or hide */
    cmVisibleChange: EventEmitter<boolean>;
    /** Event: emit on values changed */
    cmChange: EventEmitter<any[]>;
    /** Event: emit on values and selection changed */
    cmSelectionChange: EventEmitter<CascaderOption[]>;
    /**
     * Event: emit on option selected, event data：{option: any, index: number}
     */
    cmSelect: EventEmitter<{
        option: CascaderOption;
        index: number;
    }>;
    /**
     * Event: emit on option unselected, event data：{option: any, index: number}
     */
    cmUnSelect: EventEmitter<{
        option: CascaderOption;
        index: number;
    }>;
    /** Event: emit on the clear button clicked */
    cmClear: EventEmitter<any>;
    menu: ElementRef;
    onPositionChange(position: ConnectedOverlayPositionChange): void;
    cmFocus(): void;
    cmBlur(): void;
    readonly _pickerLabelCls: any;
    readonly _arrowCls: any;
    readonly _clearCls: any;
    readonly _inputCls: any;
    readonly _menuCls: any;
    /** 获取菜单中列的样式 */
    readonly _columnCls: any;
    /** 获取列中Option的样式 */
    getOptionCls(option: CascaderOption, index: number): any;
    _getLabel(): string | TemplateRef<void>;
    /** prevent input change event */
    _handlerInputChange(event: Event): void;
    /** input blur */
    _handleInputBlur(event: Event): void;
    /** input focus */
    _handleInputFocus(event: Event): void;
    /** input key down */
    _handleInputKeyDown(event: KeyboardEvent): void;
    setInputValue(inputValue: any, fireSearch?: boolean): void;
    hasInput(): boolean;
    hasSelection(): boolean;
    /** Whether the clear button is visible */
    readonly showClearIcon: boolean;
    readonly _displayRender: (label: string[], selectedOptions: CascaderOption[]) => string | TemplateRef<any>;
    readonly _intervalRender: (label: string[], selectedOptions: CascaderOption[]) => string | TemplateRef<any>;
    _buildDisplayLabel(): void;
    /** 由用户来定义点击后是否变更 */
    _isChangeOn(option: CascaderOption, index: number): boolean;
    onKeyDown(event: KeyboardEvent): void;
    _onTriggerClick(event: MouseEvent): void;
    _onTriggerMouseEnter(event: MouseEvent): void;
    _onTriggerMouseLeave(event: MouseEvent): void;
    _isClickTiggerAction(): boolean;
    _isPointerTiggerAction(): boolean;
    closeMenu(): void;
    /**
     * 显示或者隐藏菜单
     *
     * @param visible true-显示，false-隐藏
     * @param delay 延迟时间
     */
    _delaySetPopupVisible(visible: boolean, delay: number): void;
    _isPopupVisible(): boolean;
    setPopupVisible(popupVisible: boolean): void;
    /** load init data if necessary */
    _beforeVisible(): void;
    private loadRootOptions;
    _onDocumentClick(event: MouseEvent): void;
    _clearOutsideHandler(): void;
    _clearDelayTimer(): void;
    /**
     * press `up` or `down` arrow to select the sibling option.
     */
    _moveUpOrDown(isUp: boolean): void;
    _moveUp(): void;
    _moveDown(): void;
    /**
     * press `left` arrow to remove the last selected option.
     * If there is no option selected, emit `cmClear` event.
     */
    _moveLeft(): void;
    /**
     * press `right` arrow to select the next column option.
     */
    _moveRight(): void;
    /** 获取Option的值，例如，可以指定labelProperty="name"来取Name */
    getOptionLabel(option: CascaderOption): any;
    /** 获取Option的值，例如，可以指定valueProperty="id"来取ID */
    getOptionValue(option: CascaderOption): any;
    checkChange(event: any[], option: any): void;
    /** clear the input box and selected options */
    clearSelection(event: Event): void;
    onSearch(event: any, index: number): void;
    filterColumnData(): void;
    isActiveOption(option: CascaderOption, index: number): boolean;
    setColumnData(options: CascaderOption[], index: number): void;
    selectOption(option: CascaderOption, index: number): void;
    loadChildren(option: CascaderOption, index: number, success?: () => void, failure?: () => void): void;
    addActiveOption(option: CascaderOption, index: number): void;
    resetColumnData(option: CascaderOption[], index: number): void;
    unselectOption(option: CascaderOption, index: number): void;
    delActiveOption(option: CascaderOption, index: number): void;
    /**
     * 设置某列的激活的菜单选项
     *
     * @param option 菜单选项
     * @param index  选项所在的列组的索引
     */
    setActiveOption(option: CascaderOption, index: number): void;
    /**
     * 鼠标点击选项
     *
     * @param option 菜单选项
     * @param index 选项所在的列组的索引
     * @param event 鼠标事件
     */
    onOptionClick(option: CascaderOption, index: number, event: Event): void;
    /**
     * 鼠标划入选项
     *
     * @param option 菜单选项
     * @param index 选项所在的列组的索引
     * @param event 鼠标事件
     */
    onOptionMouseEnter(option: CascaderOption, index: number, event: Event): void;
    /**
     * 鼠标划出选项
     *
     * @param option 菜单选项
     * @param index 选项所在的列组的索引
     * @param event 鼠标事件
     */
    onOptionMouseLeave(option: CascaderOption, index: number, event: Event): void;
    delaySelect(option: CascaderOption, index: number, doSelect: boolean): void;
    handleTreeData(option: CascaderOption, index: number): void;
    getSubmitValue(): any[];
    onValueChange(): void;
    constructor(_elementRef: ElementRef, _render: Renderer2, _cdr: ChangeDetectorRef);
    _addHostClass(classname: string): void;
    _removeHostClass(classname: string): void;
    writeColumns(array: CascaderOption[], index: number): void;
    writeSelected(array: CascaderOption[], index: number): void;
    /**
     * Write a new value to the element.
     *
     * @Override (From ControlValueAccessor interface)
     */
    writeValue(value: any): void;
    registerOnChange(fn: (_: any) => {}): void;
    registerOnTouched(fn: () => {}): void;
    setDisabledState(isDisabled: boolean): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngAfterViewInit(): void;
}
